@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 
-from spader.detection.signal.base import UnarySignal
+from spadepp.detection.signal.base import UnarySignal
 
 class MissingValueSignal(UnarySignal):
     def __init__(self):
