@@ -1,4 +1,4 @@
-from spader.data_source import DataContainer
+from spadepp.data_source import DataContainer
 from pathlib import Path
 
 if __name__ == "__main__":
